@@ -46,9 +46,9 @@ class ReadFileJob(Job):
 
         if pre_read_result != MeshReader.PreReadResult.accepted:
             if pre_read_result == MeshReader.PreReadResult.failed:
-                result_message = Message(i18n_catalog.i18nc("@info:status Don't translate the XML tag <filename>!", "Failed to load <filename>{0}</filename>", self._filename),
+                result_message = Message(i18n_catalog.i18nc("@info:status Don't translate the XML tag <filename>!", "Failed to load <filename>{0}</filename>. The file could be corrupt or inaccessible.", self._filename),
                                          lifetime=0,
-                                         title = i18n_catalog.i18nc("@info:title", "Invalid File"))
+                                         title = i18n_catalog.i18nc("@info:title", "Unable to Open File"))
                 result_message.show()
             return
 
@@ -71,7 +71,7 @@ class ReadFileJob(Job):
             Logger.log("d", "Loading file took %0.1f seconds", end_time - begin_time)
             if self._result is None:
                 self._loading_message.hide()
-                result_message = Message(i18n_catalog.i18nc("@info:status Don't translate the XML tag <filename>!", "Failed to load <filename>{0}</filename>", self._filename), lifetime = 0, title = i18n_catalog.i18nc("@info:title", "Invalid File"))
+                result_message = Message(i18n_catalog.i18nc("@info:status Don't translate the XML tag <filename>!", "Failed to load <filename>{0}</filename>. The file could be corrupt or inaccessible.", self._filename), lifetime = 0, title = i18n_catalog.i18nc("@info:title", "Unable to Open File"))
                 result_message.show()
                 return
             self._loading_message.hide()
