@@ -1,10 +1,8 @@
 # Copyright (c) 2015 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
 
 from . import SelectionTool
 
-from UM.i18n import i18nCatalog
-i18n_catalog = i18nCatalog("uranium")
 
 def getMetaData():
     return {
